# Parent-map
Analyze parental contributions to evolved or engineered protein or DNA sequences.
Run parent-map.py without arguments to start in GUI mode.
Run parent-map.py with arguments to start in console mode.
Run parent-map.py -h for help.

